@@ -17,6 +17,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import os
+import sys
 import uuid
 import asyncio
 import pytest
@@ -43,7 +44,7 @@ async def manager(loop, port_manager):
 async def node(compute_project, manager):
 
     node = manager.create_node("test", compute_project.id, "00010203-0405-0607-0809-0a0b0c0d0e0f")
-    return await asyncio.ensure_future(node)
+    return await node
 
 
 async def test_affect_uuid():
@@ -149,6 +150,7 @@ async def test_project_delete():
     assert os.path.exists(directory) is False
 
 
+@pytest.mark.skipif(not sys.platform.startswith("win") and os.getuid() == 0, reason="Root can delete any project")
 async def test_project_delete_permission_issue():
 
     project = Project(project_id=str(uuid4()))
@@ -156,7 +158,7 @@ async def test_project_delete_permission_issue():
     assert os.path.exists(directory)
     os.chmod(directory, 0)
     with pytest.raises(aiohttp.web.HTTPInternalServerError):
-        await asyncio.ensure_future(project.delete())
+        await project.delete()
     os.chmod(directory, 700)
 
 
